from distutils.core import setup


setup(
    name='tornado_cookiejar',
    packages=['tornado_cookiejar'],
    version='0.1.1',
    description='Cookiejar with AsyncHTTPClient support on tornado',
    author='David Wong',
    author_email='stef-hw@163.com',
    url='https://github.com/hw20686832/tornado_cookiejar',
    download_url='https://github.com/hw20686832/tornado_cookiejar/archive/v0.1.1.tar.gz',
    keywords=['tornado', 'cookiejar', 'cookie'],
    classifiers=[],
)
